@@ -22,7 +22,7 @@ class PickleCache(Cache):
     def __init__(self, filename='cache.db'):
         self.filename = filename
         self._cache = self.load()
-    
+
     def load(self):
         if os.path.exists(self.filename):
             with open(self.filename, 'rb') as fh:
@@ -36,15 +36,24 @@ class PickleCache(Cache):
 
 if Redis:
     class RedisCache(Cache):
-        def __init__(self, namespace='micawber', **conn):
+        """
+        :param str namespace: key prefix.
+        :param int timeout: expiration timeout in seconds
+        """
+        def __init__(self, namespace='micawber', timeout=None, **conn):
             self.namespace = namespace
             self.key_fn = lambda self, k: '%s.%s' % (self.namespace, k)
+            self.timeout = timeout
             self.conn = Redis(**conn)
-        
+
         def get(self, k):
             cached = self.conn.get(self.key_fn(k))
             if cached:
                 return pickle.loads(cached)
-        
+
         def set(self, k, v):
-            self.conn.set(self.key_fn(k), pickle.dumps(v))
+            ck, cv = self.key_fn(k), pickle.dumps(v)
+            if self.timeout is not None:
+                self.conn.setex(ck, cv, self.timeout)
+            else:
+                self.conn.set(ck, cv)
